# Changelog
All notable changes to this project will be documented in this file.

The format is based on [Keep a Changelog](https://keepachangelog.com/en/1.0.0/),
and this project adheres to [Semantic Versioning](https://semver.org/spec/v2.0.0.html).

## [Unreleased]
### Changed

## [0.1.1] - 2018-12-19
### Changed
- Move from rst to markdown for CHANGELOG and README.
- Remove dependence on `six`.

## [0.1.0] - 2018-12-18
### Added
- Initial commit of all code.

[Unreleased]: https://github.com/cmeister2/pytokenbucket/compare/v0.1.1...HEAD
[0.1.1]: https://github.com/cmeister2/pytokenbucket/compare/v0.1.0...v0.1.1
[0.1.0]: https://github.com/cmeister2/pytokenbucket/tree/v0.1.0
